==> localnews-quartz-service-1.0.9-sources.jar: com/bxm/localnews/quartz/service/AbstractSplitTablePerMonthService.java <==
package com.bxm.localnews.quartz.service;

import java.math.BigInteger;
import java.util.Calendar;
import java.util.Map;

import com.bxm.newidea.component.tools.DateUtils;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public abstract class AbstractSplitTablePerMonthService implements PayFlowQuartzService {

    private static final Logger LOG = LoggerFactory.getLogger(AbstractSplitTablePerMonthService.class);

    //每月创建一张表
    private static final int CREATE_TABLE_MONTH_STEP = 1;

    //每张表预留10亿id，保证id全局唯一
    private static final long AUTO_INCREMENT_STEP = 1000000000L;

    protected abstract String getDefaultTableName();

    protected abstract Map<String, Object> loadTableStatus(String tableName);

    protected abstract void createTable(String tableName, long autoIncrement);

    public String generateTableName() {
        Calendar calendar = Calendar.getInstance();
        calendar.add(Calendar.MONTH, 1);
        return this.getDefaultTableName() + "_" + DateUtils.PATTERN_NO_DELIMITER_WITHOUT_DAY_FORMAT.get().format(calendar.getTime());
    }


    protected boolean existsTable(String tableName) {
        return this.loadTableStatus(tableName) != null;
    }

    private long getAutoIncrementNumber() {
        String currentTableName = this.generateTableName();
        Map<String, Object> currentTableStatus = this.loadTableStatus(currentTableName);
        if (currentTableStatus != null || !currentTableStatus.isEmpty()) {
            BigInteger currentIncrement = (BigInteger) currentTableStatus.get("Auto_increment");
            long multiple = currentIncrement.longValue() / AUTO_INCREMENT_STEP;
            return ++multiple * AUTO_INCREMENT_STEP;
        }
        return AUTO_INCREMENT_STEP;
    }

    @Override
    public void createNextTable() {
        String nextTableName = this.generateTableName();

        long nextTableIncrement = this.getAutoIncrementNumber();
        if (!this.existsTable(nextTableName)) {
            this.createTable(nextTableName, nextTableIncrement);
            LOG.info("table :" + nextTableName + " create successfully!");
        } else {
            Map<String, Object> status = this.loadTableStatus(nextTableName);
            BigInteger autoIncrement = (BigInteger) status.get("Auto_increment");
            if (autoIncrement.longValue() < nextTableIncrement) {
                LOG.warn("table :" + nextTableName + " exists,but auto_increment not incorrect!");
                this.alterTableIncrement(nextTableName, nextTableIncrement);
                LOG.info("alter" + nextTableName + " auto_increment to " + nextTableIncrement + " successfully!");
            } else {
                LOG.info("table :" + nextTableName + " already exists!");
            }
        }
    }

    protected abstract void alterTableIncrement(String tableName, long autoIncrement);

}

==> localnews-quartz-service-1.1.0-20181017.035229-1-sources.jar: com/bxm/localnews/quartz/service/AbstractSplitTablePerMonthService.java <==
package com.bxm.localnews.quartz.service;

import com.bxm.localnews.common.exception.DataException;
import com.bxm.newidea.component.tools.DateUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.math.BigInteger;
import java.util.Calendar;
import java.util.Date;
import java.util.Map;

public abstract class AbstractSplitTablePerMonthService implements PayFlowQuartzService {

    private static final Logger LOG = LoggerFactory.getLogger(AbstractSplitTablePerMonthService.class);

    //每月创建一张表
    private static final int CREATE_TABLE_MONTH_STEP = 1;

    //每张表预留10亿id，保证id全局唯一
    private static final long AUTO_INCREMENT_STEP = 1000000000L;

    protected abstract String getDefaultTableName();

    protected abstract Map<String, Object> loadTableStatus(String tableName);

    protected abstract void createTable(String tableName, long autoIncrement);

    public String generateTableName(Date date) {
        return this.getDefaultTableName() + "_" + DateUtils.PATTERN_NO_DELIMITER_WITHOUT_DAY_FORMAT.get().format(date);
    }

    protected String generateQueryTableName(Date startTime, Date endTime) throws DataException {
        if (startTime.after(endTime)) {
            throw new DataException("结束时间不能小于开始时间");
        }
        if (DateUtils.getField(startTime, Calendar.MONTH) != DateUtils.getField(endTime, Calendar.MONTH)) {
            throw new DataException("只能按月查询");
        }
        return this.generateTableName(startTime);
    }

    protected boolean existsTable(String tableName) {
        return this.loadTableStatus(tableName) != null;
    }

    private long getAutoIncrementNumber() {
        String currentTableName = this.generateTableName(new Date());
        Map<String, Object> currentTableStatus = this.loadTableStatus(currentTableName);
        if (currentTableStatus != null || !currentTableStatus.isEmpty()) {
            BigInteger currentIncrement = (BigInteger) currentTableStatus.get("Auto_increment");
            long multiple = currentIncrement.longValue() / AUTO_INCREMENT_STEP;
            return ++multiple * AUTO_INCREMENT_STEP;
        }
        return AUTO_INCREMENT_STEP;
    }

    @Override
    public void createNextTable() {
        String nextTableName = this.generateTableName(new Date());

        long nextTableIncrement = this.getAutoIncrementNumber();
        if (!this.existsTable(nextTableName)) {
            this.createTable(nextTableName, nextTableIncrement);
            LOG.info("table :" + nextTableName + " create successfully!");
        } else {
            Map<String, Object> status = this.loadTableStatus(nextTableName);
            BigInteger autoIncrement = (BigInteger) status.get("Auto_increment");
            if (autoIncrement.longValue() < nextTableIncrement) {
                LOG.warn("table :" + nextTableName + " exists,but auto_increment not incorrect!");
                this.alterTableIncrement(nextTableName, nextTableIncrement);
                LOG.info("alter" + nextTableName + " auto_increment to " + nextTableIncrement + " successfully!");
            } else {
                LOG.info("table :" + nextTableName + " already exists!");
            }
        }
    }

    protected abstract void alterTableIncrement(String tableName, long autoIncrement);

}
